@@ -16,7 +16,7 @@ def version():
 
     :return: 返回版本号
     """
-    return '1.1133'
+    return '1.1134'
 
 
 def f_debug():
@@ -52,17 +52,24 @@ def f_debug():
     # 欢迎您进入Fishconsole的调试控制模块，如果您想了解这个集合是如何运行的，请将mod的参数改为False
     # ，相信我，输出的内容可能会很多，它们能帮你了解这个模块核心组件的全部运行过程，我呢，只是一个职高生，做这
     # 个完全是为爱发电，所以，虽然我的模块不会很好，但正在努力前行——鱼几斤（2022/4/24）
-    from Fishconsole import logs, files, helps,Fishsys
-    import os, pandas as pd
-    from openpyxl.utils import get_column_letter
-    from pandas import ExcelWriter
-    import numpy as np
-    import threading
+    from Fishconsole import logs, files, helps, Fishsys
+    try:
+        import os, pandas as pd
+        from openpyxl.utils import get_column_letter
+        from pandas import ExcelWriter
+        import numpy as np
+        import threading
+        from pip._internal import main
+    except:
+        logs.安全退出("fcv依赖包导入出错，程序无法运行")
+
+
     def to_excel_auto_column_weight(df: pd.DataFrame, writer: ExcelWriter, sheet_name):
         """DataFrame保存为excel并自动设置列宽"""
         df.to_excel(writer, sheet_name=sheet_name, index=False)
         #  计算表头的字符宽度
         column_widths = (
+
             df.columns.to_series().apply(lambda x: len(x.encode('gbk'))).values
         )
         #  计算每列的最大字符宽度
@@ -336,6 +343,34 @@ def f_debug():
             print(logs.日志(f"Fishconsole fcv_debug [ 2.0 ]","蓝色"))
 
 
+        elif b[0] in ["pip", "PIP"]:
+            未选触发器 = True
+            for a in b:
+                # 循环检测
+                if a == "install":
+                    print(logs.日志("Fishconsole fcv_debug PIP》安装和更新开始","蓝色"))
+                    未选触发器 = False
+                    res=Fishsys.官网存活性检测("https://pypi.org/",3)
+                    if res:
+                        try:
+                            main(['install', '--upgrade','pip'])
+                            main(['install',f'{b[2]}'])
+                            main(['install', '--upgrade' , f'{b[2]}'])
+                        except:
+                            print(logs.日志("Fishconsole fcv_debug PIP》未知错误","蓝色"))
+                        print(logs.日志("Fishconsole fcv_debug PIP》安装和更新结束", "蓝色"))
+                    else:
+                        print(logs.日志("官网连接失败","红色"))
+                        print(logs.日志("Fishconsole fcv_debug PIP》安装和更新结束", "蓝色"))
+            if 未选触发器:
+                print(logs.分割线(f"这是pip的简介", "fcv_debug console", 色选="红色"))
+                print("他的作用就是执行pip的指令（本来用execute可以解决，但是jupyter不行）")
+                print("可用参数")
+                print("install"
+                      "")
+                print("如果想了解具体的用法，请在终端中键入'help'或者'?'")
+
+
 
         elif b[0] in ["help", "?", "？","HELP"]:
             helps.帮助()
