@@ -302,12 +302,30 @@ def 帮助():
                         "强制类型检测",
                         "讯飞云控",
                         "官网存活性检测",
+                        "邮件发送"
                     ])
                     Fishsys.系统日志(f"用户请求启动{res}", "helps主程序", HEI)
                     if res is None:
                         logs.安全退出("用户取消了操作")
                     # noinspection PyAssignmentToLoopOrWithParameter
                     for a in res:
+                        if a == "邮件发送":
+                            window.弹窗(
+                                "就是发送一个邮件,他有这几项参数\n"
+                                "-----------------------------\n\n"
+                                "邮件发送账号:邮件发送账号\n"
+                                "邮件接收账号:邮件接收账号\n"
+                                "授权码:授权码\n"
+                                "SMTP服务器地址:SMTP服务器地址\n"
+                                "端口号:端口号\n"
+                                "HTML正文内容:HTML正文内容\n"
+                                "收件人姓名:\n"
+                                "邮件标题:邮件标题\n"
+                                "附件地址:附件地址\n"
+                                "发件人姓名:发件人姓名\n\n\n"
+                                "-------------------\n"
+                                "其中必须要设置的参数是：邮件发送的账号，邮件接收的账号，授权码，配置好这些后，我们就可以为您发送一封预设邮件"
+                                , "邮件发送", "ok")
                         if a == "官网存活性检测":
                             window.弹窗(
                                 "其实就是一爬虫，看官网存不存在，也可以用来检测联网没有\n"
